API docs for “spamfighter.core.commands.errors.SkipToFallthroughError”

# Class s.c.c.e.SkipToFallthroughError(BaseCommandException):

Part of spamfighter.core.commands.errors View Source View In Hierarchy

В firewall не нашлось метки для skip to...

Method | __init__ | Undocumented

Inherited from BaseCommandException:

Method | getCode | Undocumented
Method | getMessage | Undocumented
Method | __str__ | Undocumented

def __init__(self, label): (source)
overrides spamfighter.core.commands.errors.BaseCommandException.__init__
Undocumented